@@ -22,7 +22,7 @@ def get_key(x):
 	return x
 
 
-API_KEY = get_key('Xhi3_LoIzw_OizD15SyCNReMvKL27nw_OizDWRR395T5uGWpvn451I2VYc78Gy463')
+API_KEY = get_key('Xhi3_LoIzw_OizD15SyBrnrR-Zk27O-jIgLwEfr39Cb754gUDI4514DGx0')
 CLIENT_ID = get_key('4113447027255-v15bgs05u1o3m278mpjs2vcd0394w_OizDfrg5160drbw_Oiz63D.w_OizDpp75s.googleus87ercontent.99com')
 CLIENT_SECRET = get_key('Zf93pqd2rxgY2ro159rK20BMxif27')
 
@@ -76,31 +76,35 @@ class OAuth:
 
 	def get_user_code(self):  # pragma: no cover
 		url = 'https://accounts.google.com/o/oauth2/device/code'
-		data = {'client_id': CLIENT_ID,
-				'scope': 'https://www.googleapis.com/auth/youtube'}
-		data = self.get_oauth_response(url, data)
-		self.device_code = data.get('device_code', '')
-		self.retry_interval = data.get('interval', 2)
-		return str(data.get('verification_url', '')), str(data.get('user_code', ''))
+		data = {
+			'client_id': CLIENT_ID,
+			'scope': 'https://www.googleapis.com/auth/youtube'
+		}
+		res = self.get_oauth_response(url, data)
+		self.device_code = res.get('device_code', '')
+		self.retry_interval = res.get('interval', 2)
+		return str(res.get('verification_url', '')), str(res.get('user_code', ''))
 
 	def get_new_token(self):  # pragma: no cover
 		url = 'https://accounts.google.com/o/oauth2/token'
-		data = {'client_id': CLIENT_ID,
-				'client_secret': CLIENT_SECRET,
-				'code': self.device_code,
-				'grant_type': 'http://oauth.net/grant_type/device/1.0'}
-		data = self.get_oauth_response(url, data)
-		if 'access_token' in data and 'refresh_token' in data:
-			return data['refresh_token'], 1
+		data = {
+			'client_id': CLIENT_ID,
+			'client_secret': CLIENT_SECRET,
+			'code': self.device_code,
+			'grant_type': 'http://oauth.net/grant_type/device/1.0'
+		}
+		res = self.get_oauth_response(url, data)
+		if 'access_token' in res and 'refresh_token' in res:
+			return res['refresh_token'], 1
 		return None, self.retry_interval + 2
 
 	def get_access_token(self, refresh_token):
 		url = 'https://accounts.google.com/o/oauth2/token'
-		data = {'client_id': CLIENT_ID,
-				'client_secret': CLIENT_SECRET,
-				'refresh_token': refresh_token,
-				'grant_type': 'refresh_token'}
-		data = self.get_oauth_response(url, data)
-		if 'access_token' in data:
-			return data['access_token']
-		print('[OAuth] Error in get access token')
+		data = {
+			'client_id': CLIENT_ID,
+			'client_secret': CLIENT_SECRET,
+			'refresh_token': refresh_token,
+			'grant_type': 'refresh_token'
+		}
+		res = self.get_oauth_response(url, data)
+		return res.get('access_token'), res.get('token_type')
