@@ -45,6 +45,15 @@ except ImportError:
 	ISO3166 = [(x[1][0], x[1][2]) for x in language.getLanguageList() if x[1][2] != 'EN']
 
 
+def default_language():
+	lang = language.getLanguage().split('_')
+	if len(lang) > 1:
+		if lang[1] == 'EN':
+			lang[1] = ''
+		return lang
+	return ['', '']
+
+
 config.plugins.YouTube = ConfigSubsection()
 config.plugins.YouTube.saveHistory = ConfigYesNo(default=True)
 config.plugins.YouTube.searchResult = ConfigSelection(default='24',
@@ -54,10 +63,10 @@ config.plugins.YouTube.searchResult = ConfigSelection(default='24',
 		('24', '24'),
 		('50', '50')])
 config.plugins.YouTube.searchRegion = ConfigSelection(
-	default=language.getLanguage().split('_')[1] if language.getLanguage().split('_')[1] != 'EN' else '',
+	default=default_language()[1],
 	choices=[('', _('All'))] + [(x[1], x[0]) for x in ISO3166])
 config.plugins.YouTube.searchLanguage = ConfigSelection(
-	default=language.getLanguage().split('_')[0],
+	default=default_language()[0],
 	choices=[('', _('All'))] + [(x[1][1], x[1][0]) for x in language.getLanguageList()])
 config.plugins.YouTube.searchOrder = ConfigSelection(default='relevance',
 	choices=[('relevance', _('Relevance')),
@@ -719,7 +728,7 @@ class YouTubeMain(Screen):
 		if not video_url:  # Get and remember video url
 			er = 'Video url not found!'
 			try:
-				video_url = self.ytdl.extract(video_id)
+				video_url = self.ytdl.extract(video_id, self.ytapi.get_yt_auth())
 			except Exception as e:
 				er = e
 				print('[YouTube] Error in extract info:', er)
@@ -805,10 +814,7 @@ class YouTubeMain(Screen):
 				config.plugins.YouTube.login.value):
 			from .YouTubeApi import YouTubeApi
 			self.ytapi = YouTubeApi(refresh_token)
-			if self.ytapi.access_token:
-				self.is_auth = True
-			else:
-				self.is_auth = False
+			self.is_auth = self.ytapi.is_auth()
 
 	def mySubscriptions(self):
 		videos = []
