@@ -105,15 +105,39 @@ class YouTubeVideoUrl():
 
 	@staticmethod
 	def _extract_n_function_name(jscode):
-		nfunc, idx = search(
-			r'\.get\("n"\)\)&&\(b=(?P<nfunc>[a-zA-Z0-9$]+)(?:\[(?P<idx>\d+)\])?\([a-zA-Z0-9]\)',
-			jscode
+		func_name, idx = search(
+			r'''(?x)
+				(?:
+					\.get\("n"\)\)&&\(b=|
+					(?:
+						b=String\.fromCharCode\(110\)|
+						(?P<str_idx>[a-zA-Z0-9_$.]+)&&\(b="nn"\[\+(?P=str_idx)\]
+					)
+					(?:
+						,[a-zA-Z0-9_$]+\(a\))?,c=a\.
+						(?:
+							get\(b\)|
+							[a-zA-Z0-9_$]+\[b\]\|\|null
+						)\)&&\(c=|
+					\b(?P<var>[a-zA-Z0-9_$]+)=
+				)(?P<nfunc>[a-zA-Z0-9_$]+)(?:\[(?P<idx>\d+)\])?\([a-zA-Z]\)
+				(?(var),[a-zA-Z0-9_$]+\.set\("n"\,(?P=var)\),(?P=nfunc)\.length)
+			''', jscode
 		).group('nfunc', 'idx')
+		if not func_name:
+			print('[YouTubeVideoUrl] Falling back to generic n function search')
+			return search(
+				r'''(?xs)
+					(?:(?<=[^\w$])|^)       # instead of \b, which ignores $
+					(?P<name>(?!\d)[a-zA-Z\d_$]+)\s*=\s*function\((?!\d)[a-zA-Z\d_$]+\)
+					\s*\{(?:(?!};).)+?["']enhanced_except_
+				''', jscode
+			).group('name')
 		if not idx:
-			return nfunc
+			return func_name
 		if int(idx) == 0:
 			real_nfunc = search(
-				r'var %s\s*=\s*\[([a-zA-Z_$][\w$]*)\];' % (escape(nfunc), ),
+				r'var %s\s*=\s*\[([a-zA-Z_$][\w$]*)\];' % (escape(func_name), ),
 				jscode
 			)
 			if real_nfunc:
@@ -292,7 +316,7 @@ class YouTubeVideoUrl():
 					print('[YouTubeVideoUrl] Failed to parse web JSON')
 		return None, None
 
-	def _extract_player_response(self, video_id, client):
+	def _extract_player_response(self, video_id, yt_auth, client):
 		player_id = None
 		url = 'https://www.youtube.com/youtubei/v1/player?prettyPrint=false'
 		data = {
@@ -308,6 +332,8 @@ class YouTubeVideoUrl():
 			'Origin': 'https://www.youtube.com',
 			'X-YouTube-Client-Name': client
 		}
+		if yt_auth:
+			headers['Authorization'] = yt_auth
 		if client == 5:
 			VERSION = '19.09.3'
 			USER_AGENT = 'com.google.ios.youtube/%s (iPhone14,3; U; CPU iOS 15_6 like Mac OS X)' % VERSION
@@ -367,7 +393,7 @@ class YouTubeVideoUrl():
 			print('[YouTubeVideoUrl] Failed to parse JSON')
 			return None, None
 
-	def _real_extract(self, video_id):
+	def _real_extract(self, video_id, yt_auth):
 		IGNORE_VIDEO_FORMAT = (
 			'43', '44', '45', '46',  # webm
 			'82', '83', '84', '85',  # 3D
@@ -394,7 +420,7 @@ class YouTubeVideoUrl():
 			print('[YouTubeVideoUrl] skip DASH MP4 format')
 			self.use_dash_mp4 = DASHMP4_FORMAT
 
-		player_response, player_id = self._extract_player_response(video_id, 30)
+		player_response, player_id = self._extract_player_response(video_id, yt_auth, 30)
 		if not player_response:
 			raise RuntimeError('Player response not found!')
 
@@ -404,14 +430,14 @@ class YouTubeVideoUrl():
 				player_response, player_id = self._extract_web_response(video_id)
 			else:
 				print('[YouTubeVideoUrl] Got wrong player response, try ios client')
-				player_response, player_id = self._extract_player_response(video_id, 5)
+				player_response, player_id = self._extract_player_response(video_id, yt_auth, 5)
 
 		is_live = self.try_get(player_response, lambda x: x['videoDetails']['isLive'])
 		playability_status = player_response.get('playabilityStatus', {})
 
 		if not is_live and playability_status.get('status') == 'LOGIN_REQUIRED':
 			print('[YouTubeVideoUrl] Age gate content')
-			player_response, player_id = self._extract_player_response(video_id, 85)
+			player_response, player_id = self._extract_player_response(video_id, yt_auth, 85)
 			if not player_response:
 				raise RuntimeError('Age gate content player response not found!')
 
@@ -447,7 +473,7 @@ class YouTubeVideoUrl():
 						url = fmt.get('url')
 						if url:
 							break
-			if not url:  # pragma: no cover
+			if not url and streaming_formats:  # pragma: no cover
 				url = streaming_formats[0].get('url', '')
 
 		if not url:
@@ -482,11 +508,11 @@ class YouTubeVideoUrl():
 
 		return str(url)
 
-	def extract(self, video_id):
+	def extract(self, video_id, yt_auth=None):
 		error_message = None
 		for _ in range(3):
 			try:
-				return self._real_extract(video_id)
+				return self._real_extract(video_id, yt_auth)
 			except Exception as ex:
 				if ex is None:
 					print('No supported formats found, trying again!')
