@@ -10,7 +10,7 @@ from Components.config import config, ConfigSubsection, ConfigNothing, ConfigSel
 from Components.Label import Label
 from Components.Sources.List import List
 from Components.Sources.Boolean import Boolean
-from Components.SystemInfo import SystemInfo
+from Components.SystemInfo import BoxInfo
 from Components.VolumeControl import VolumeControl
 from Components.UsageConfig import originalAudioTracks, visuallyImpairedCommentary
 from Components.Converter.ServiceInfo import StdAudioDesc
@@ -23,10 +23,11 @@ from enigma import iPlayableService, eTimer, eSize, eDVBDB, eServiceReference, e
 FOCUS_CONFIG, FOCUS_STREAMS = range(2)
 [PAGE_AUDIO, PAGE_SUBTITLES] = ["audio", "subtitles"]
 
-
 selectionpng = LoadPixmap(cached=True, path=resolveFilename(SCOPE_GUISKIN, "icons/audioselectionmark.png"))
 
-
+def isIPTV(service):
+	path = service and service.getPath()
+	return path and not path.startswith("/") and service.type in [0x1, 0x1001, 0x138A, 0x1389]
 class AudioSelection(ConfigListScreen, Screen):
 	def __init__(self, session, infobar=None, page=PAGE_AUDIO):
 		Screen.__init__(self, session)
@@ -84,10 +85,14 @@ class AudioSelection(ConfigListScreen, Screen):
 		self.focus = FOCUS_STREAMS
 		self.settings.menupage.addNotifier(self.fillList)
 
+	def saveAVDict(self):
+		eDVBDB.getInstance().saveIptvServicelist()
+
 	def fillList(self, arg=None):
 		streams = []
 		conflist = []
 		selectedidx = 0
+		is_downmix = False
 
 		self["key_blue"].setBoolean(False)
 
@@ -97,21 +102,25 @@ class AudioSelection(ConfigListScreen, Screen):
 			self.setTitle(_("Select audio track"))
 			service = self.session.nav.getCurrentService()
 			self.audioTracks = audio = service and service.audioTracks()
-			n = audio and audio.getNumberOfTracks() or 0
-			if SystemInfo["CanDownmixAC3"]:
+			track_num = audio and audio.getNumberOfTracks() or 0
+			if BoxInfo.getItem("CanDownmixAC3") and track_num > 0 and config.usage.setup_level.index >= 1:
 				downmix_ac3_value = config.av.downmix_ac3.value
 				if downmix_ac3_value in ("downmix", "passthrough"):
 					self.settings.downmix = ConfigSelection(choices=[("downmix", _("Downmix")), ("passthrough", _("Passthrough"))], default=downmix_ac3_value)
 					self.settings.downmix.addNotifier(self.changeAC3Downmix, initial_call=False)
 					extra_text = " - AC3"
-					if SystemInfo["CanDownmixDTS"]:
+					if BoxInfo.getItem("CanDownmixDTS"):
 						extra_text += ",DTS"
-					if SystemInfo["CanDownmixAAC"]:
+					if BoxInfo.getItem("CanDownmixAAC"):
 						extra_text += ",AAC"
 					conflist.append((_("Multi channel downmix") + extra_text, self.settings.downmix))
 					self["key_red"].setBoolean(True)
+					is_downmix = True
+			if not is_downmix:
+				conflist.append(('',))
+				self["key_red"].setBoolean(False)
 
-			if n > 0:
+			if track_num > 0:
 				self.audioChannel = service.audioChannel()
 				if self.audioChannel:
 					choicelist = [("0", _("left")), ("1", _("stereo")), ("2", _("right"))]
@@ -123,7 +132,7 @@ class AudioSelection(ConfigListScreen, Screen):
 					conflist.append(('',))
 					self["key_green"].setBoolean(False)
 				selectedAudio = self.audioTracks.getCurrentTrack()
-				for x in range(n):
+				for x in range(track_num):
 					number = str(x + 1)
 					i = audio.getTrackInfo(x)
 					languages = i.getLanguage().split('/')
@@ -265,10 +274,10 @@ class AudioSelection(ConfigListScreen, Screen):
 	def changeAC3Downmix(self, configElement):
 		config.av.downmix_ac3.value = configElement.value
 		config.av.downmix_ac3.save()
-		if SystemInfo["CanDownmixDTS"]:
+		if BoxInfo.getItem("CanDownmixDTS"):
 			config.av.downmix_dts.value = configElement.value
 			config.av.downmix_dts.save()
-		if SystemInfo["CanDownmixAAC"]:
+		if BoxInfo.getItem("CanDownmixAAC"):
 			config.av.downmix_aac.value = configElement.value
 			config.av.downmix_aac.save()
 
@@ -279,8 +288,13 @@ class AudioSelection(ConfigListScreen, Screen):
 	def changeAudio(self, audio):
 		track = int(audio)
 		if isinstance(track, int):
-			if self.session.nav.getCurrentService().audioTracks().getNumberOfTracks() > track:
+			service = self.session.nav.getCurrentService()
+			ref = self.session.nav.getCurrentlyPlayingServiceReference()
+			#ref = ref and eServiceReference(ref.toString())
+			if service.audioTracks().getNumberOfTracks() > track:
 				self.audioTracks.selectTrack(track)
+				if isIPTV(ref):
+					self.saveAVDict()
 
 	def keyLeft(self):
 		if self.focus == FOCUS_CONFIG:
@@ -382,6 +396,8 @@ class AudioSelection(ConfigListScreen, Screen):
 			if self.settings.menupage.getValue() == PAGE_AUDIO and cur[0] is not None:
 				self.changeAudio(cur[0])
 				self.__updatedInfo()
+			ref = self.session.nav.getCurrentlyPlayingServiceReference()
+			#ref = ref and eServiceReference(ref.toString())
 			if self.settings.menupage.getValue() == PAGE_SUBTITLES and cur[0] is not None:
 				if config.subtitles.show.value and self.infobar.selected_subtitle and self.infobar.selected_subtitle[:4] == cur[0][:4]:
 					self.infobar.enableSubtitle(None)
@@ -392,6 +408,8 @@ class AudioSelection(ConfigListScreen, Screen):
 					config.subtitles.show.value = True
 					self.infobar.enableSubtitle(cur[0][:5])
 					self.__updatedInfo()
+				if isIPTV(ref):
+					self.saveAVDict()
 			self.close(0)
 		elif self.focus == FOCUS_CONFIG:
 			self.keyRight()
